@@ -16,26 +16,24 @@ data <- adaptation_level
 group1_part2 <- data %>% filter(group == 1 & part == 2)
 group2_part2 <- data %>% filter(group == 2 & part == 2)
 
-## ---- message=FALSE, warning=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+## ---- message=FALSE, warning=FALSE, results = 'hide'--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 fit1 <- b_linear(x=group1_part2$sequence,
                  y=group1_part2$response,
                  s=group1_part2$subject,
-                 iter=500, warmup=100, chains=1)
+                 iter=500, warmup=250, chains=1)
 
 fit2 <- b_linear(x=group2_part2$sequence,
                  y=group2_part2$response,
                  s=group2_part2$subject,
-                 iter=500, warmup=100, chains=1)
+                 iter=500, warmup=250, chains=1)
 
 ## ---- message=FALSE, warning=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 # trace plots
 plot_trace(fit1)
 plot_trace(fit2)
 
-# check fit
-print(fit1)
-
-# the command below is commented out for the sake of brevity
+# the commands below are commented out for the sake of brevity
+#print(fit1)
 #print(fit2)
 
 # visual inspection
@@ -54,7 +52,6 @@ plot_means_difference(fit1, fit2=fit2, par="intercept")
 ## ---- message=FALSE, warning=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 plot_distributions(fit1, fit2) +
   labs(title="Part II", x="measurement number", y="") +
-  theme(legend.position=) +
   theme(legend.position="none") +
   scale_x_continuous(limits=c(1, 10), breaks=seq(1:10)) +
   ylim(0, 10)
