@@ -28,10 +28,11 @@ fit_red <- b_color(colors=data_red, chains=1, iter=500, warmup=100)
 
 # inspect
 plot_trace(fit_red)
-print(fit_red)
 plot_hsv(fit_red)
+# the command below is commented out for the sake of brevity
+#print(fit_red)
 
-## ---- message=FALSE, warning=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+## ---- message=FALSE, warning=FALSE, results = 'hide'--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 # green
 data_green <- data_all %>% filter(stimuli == "green")
 data_green <- data.frame(r=data_green$r,
