@@ -27,11 +27,11 @@ control_rt$subject <- control_rt$subject - 21
 # fit
 rt_control_fit <- b_reaction_time(t=control_rt$rt,
                                   s=control_rt$subject,
-                                  chains=1, iter=500, warmup=100)
+                                  chains=1, iter=500, warmup=250)
 
 rt_test_fit <- b_reaction_time(t=test_rt$rt,
                                s=test_rt$subject,
-                                  chains=1, iter=500, warmup=10)
+                                  chains=1, iter=500, warmup=250)
 
 ## ---- message=FALSE, warning=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 # plot trace
@@ -40,10 +40,8 @@ plot_trace(rt_control_fit)
 plot_trace(rt_test_fit)
 
 ## ---- message=FALSE, warning=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-# check fit (Rhat and n_eff)
-print(rt_control_fit)
-
-# the command below is commented out for the sake of brevity
+# the commands below are commented out for the sake of brevity
+#print(rt_control_fit)
 #print(rt_test_fit)
 
 ## ---- eval=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
