@@ -3,7 +3,7 @@
 knitr::opts_chunk$set(fig.width=6, fig.height=4.5)
 options(width=800)
 
-## ---- message=FALSE, warning=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+## ---- message=FALSE, warning=FALSE, results = 'hide'--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 # libs
 library(bayes4psy)
 library(ggplot2)
@@ -11,6 +11,19 @@ library(ggplot2)
 # load data
 data <- stroop_simple
 
+# reading incongruent vs reading neutral
+ri_vs_rn <- data$reading_incongruent - data$reading_neutral
+
+# fit
+fit_ri_vs_rn <- b_ttest(ri_vs_rn,
+                        iter=4000, warmup=500, chains=1)
+
+## ---- message=FALSE, warning=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+# libs
+# compare the fit with 0
+comparison <- compare_means(fit_ri_vs_rn, mu=0)
+
+## ---- message=FALSE, warning=FALSE, results = 'hide'--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 # priors
 mu_prior <- b_prior(family="normal", pars=c(60, 30))
 sigma_prior <- b_prior(family="uniform", pars=c(0, 120))
@@ -20,19 +33,19 @@ priors <- list(c("mu", mu_prior),
 # fit
 fit_reading_neutral <- b_ttest(data$reading_neutral,
                                priors=priors,
-                               iter=500, warmup=100, chains=1)
+                               iter=1000, warmup=500, chains=1)
 
 fit_reading_incongruent <- b_ttest(data$reading_incongruent,
                                    priors=priors,
-                                   iter=500, warmup=100, chains=1)
+                                   iter=1000, warmup=500, chains=1)
 
 fit_naming_neutral <- b_ttest(data$naming_neutral,
                               priors=priors,
-                              iter=500, warmup=100, chains=1)
+                              iter=1000, warmup=500, chains=1)
 
 fit_naming_incongruent <- b_ttest(data$naming_incongruent,
                                   priors=priors,
-                                  iter=500, warmup=100, chains=1)
+                                  iter=1000, warmup=500, chains=1)
 
 ## ---- message=FALSE, warning=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 # trace plots
@@ -42,10 +55,11 @@ fit_naming_incongruent <- b_ttest(data$naming_incongruent,
 plot_trace(fit_naming_incongruent)
 
 # check fit
+# the commands below are commented out for the sake of brevity
 #print(fit_reading_neutral)
 #print(fit_reading_incongruent)
 #print(fit_naming_neutral)
-print(fit_naming_incongruent)
+#print(fit_naming_incongruent)
 
 # visual inspection
 #plot(fit_reading_neutral)
